@@ -5,7 +5,7 @@ DateTime   : 2021/02/21 16:07
 Author     : ZhangYafei
 Description: 
 """
-from _settings import *
+from settings import *
 import random
 
 
